/*
  Copyright 2018-2021, Barcelona Supercomputing Center (BSC), Spain
  Copyright 2015-2021, Johannes Gutenberg Universitaet Mainz, Germany

  This software was partially supported by the
  EC H2020 funded project NEXTGenIO (Project ID: 671951, www.nextgenio.eu).

  This software was partially supported by the
  ADA-FS project under the SPPEXA project funded by the DFG.

  This file is part of GekkoFS.

  GekkoFS is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  GekkoFS is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with GekkoFS.  If not, see <https://www.gnu.org/licenses/>.

  SPDX-License-Identifier: GPL-3.0-or-later
*/

#include <filesystem>

#include <api/env.hpp>
#include <api/info.hpp>
#include <api/connection.hpp>
#include <api/detail/connection_impl.hpp>

#include <global/env_util.hpp>

namespace gkfs::api::fs {

////////////////////////////////////////////////////////////////////////////////
// implementation of the public API                                           //
////////////////////////////////////////////////////////////////////////////////
connection::connection()
    : pimpl_(new connection::impl(gkfs::env::get_var(
              gkfs::env::HOSTS_FILE, gkfs::config::hostfile_path))) {}

connection::connection(const std::string& hostfile)
    : pimpl_(new connection::impl(hostfile)) {}

connection::~connection() = default;

std::size_t
connection::put(const void* buffer, size_t size,
                const std::filesystem::path& gkfs_filename,
                off_t start_offset) const {
    return pimpl_->put(buffer, size, gkfs_filename, start_offset);
}


} // namespace gkfs::api::fs